"use client";

import { Link } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useNotifications } from "@/servers/data/use-notification";
import { Bell } from "lucide-react";
import moment from "moment";
import "moment/locale/ar";
import { useLocale, useTranslations } from "next-intl";
import { useEffect, useRef, useState } from "react";

export default function NotificationsDropdown() {
	const [isOpen, setIsOpen] = useState(false);
	const dropdownRef = useRef<HTMLDivElement>(null);
	const t = useTranslations();
	const locale = useLocale();

	const {
		notifications,
		unreadCount,
		isLoading,
		refetch
	} = useNotifications();

	// Close dropdown when clicking outside
	useEffect(() => {
		function handleClickOutside(event: MouseEvent) {
			if (dropdownRef.current && !dropdownRef.current.contains(event.target as Node)) {
				setIsOpen(false);
				refetch();
			}
		}

		document.addEventListener("mousedown", handleClickOutside);
		return () => {
			document.removeEventListener("mousedown", handleClickOutside);
		};
	}, []);


	return (
		<div className="relative" ref={dropdownRef}>
			<button
				className="relative p-2 text-gray-600 hover:text-gray-900 focus:outline-none"
				onClick={() => setIsOpen(!isOpen)}
				aria-label="Notifications"
			>
				<Bell className="h-[22px] w-[22px] text-white" />
				{unreadCount > 0 && (
					<span className="absolute top-[5px] right-[7px] flex h-[10px] w-[10px] items-center justify-center rounded-full bg-red-500 text-[9px] text-white" />
				)}
			</button>

			{isOpen && (
				<div className="absolute right-0 -mt-[4px] w-80 rounded-lg bg-white shadow-xl ring-1 ring-black ring-opacity-5 z-[999]">
					<div className="p-4">
						<div className="flex items-center justify-between mb-4">
							<h3 className="text-lg text-black font-medium">{t("Notifications")}</h3>
							{unreadCount > 0 && <h3 className="text-base text-white bg-red-600 rounded-full w-6 h-6 text-center font-medium">{unreadCount}</h3>}
						</div>

						<div className="max-h-60 overflow-y-auto scrollbar-thin scrollbar-thumb-gray-300 scrollbar-track-transparent">
							{isLoading ? (
								<div className="flex justify-center py-4">
									<div className="animate-spin rounded-full h-6 w-6 border-b-2 border-blue-600"></div>
								</div>
							) : notifications?.filter((notification: any) => !notification.seen)?.length > 0 ? (
								<ul className="space-y-3">
									{notifications?.filter((notification: any) => !notification.seen)?.map((notification: any) => (
										<li
											key={notification.id}
											className={cn(
												"p-3 rounded-md transition-colors cursor-pointer",
												!notification.seen ? "bg-gray-50" : "bg-blue-50"
											)}
										>
											<p className="text-sm text-gray-600 mt-1">{locale === "ar" ? notification.description_ar : notification.description_en}</p>
											<div className="flex justify-between">
												<span dir="rtl" className="text-xs text-gray-500">
													{locale === "ar"
														? moment(notification.created_at).locale("ar").fromNow()
														: moment(notification.created_at).fromNow()}
												</span>
											</div>
										</li>
									))}
								</ul>
							) : (
								<p className="text-center text-gray-500 py-4">{t("No notifications found")}</p>
							)}
						</div>

						<div className="mt-4 pt-3 border-t border-gray-200">
							<Link
								href="/notifications"
								className="block text-center text-sm text-blue-600 hover:text-blue-800"
								onClick={() => setIsOpen(false)}
							>
								{t("View all notifications")}
							</Link>
						</div>
					</div>
				</div>
			)}
		</div>
	);
} 